@@ -9,5 +9,11 @@ our @ISA =
   qw(Apache::Session::Browseable::Store::DBI Apache::Session::Store::Postgres);
 our $VERSION = '1.2.2';
 
+sub connection {
+    my($self,$session)=@_;
+    $self->SUPER::connection($session);
+    $self->{dbh}->{pg_enable_utf8} = 1;
+}
+
 1;
 
